# Configuration

## Runtime parameters

- `host`
- `port`
- `workers`

## Environment variables

- `VYRO_ENV`
- `VYRO_SECRET_KEY`
- `VYRO_WORKERS`
- `VYRO_LOG_SAMPLE_INFO`
- `VYRO_LOG_SAMPLE_WARN`
- `VYRO_LOG_SAMPLE_ERROR`

Use `vyro doctor --strict` in CI for production readiness checks.
